@@ -5,6 +5,8 @@ from .static import DOCKERFILE, SERVER
 import requests
 from functools import partial
 import signal
+import subprocess
+import shutil
 
 @click.command()
 def build():
@@ -16,25 +18,34 @@ def build():
     # Try cloning deployment files and building image
     click.echo("🤖 Building your Docker image (this may take a while so you might wanna grab some coffee ☕)...")
 
-    with open('./Dockerfile', 'w') as f:
+    os.makedirs("./catacomb-out", exist_ok=True)
+    with open('./catacomb-out/Dockerfile', 'w') as f:
         f.write(DOCKERFILE)
-    with open('./server.py', 'w') as f:
+    with open('./catacomb-out/server.py', 'w') as f:
         f.write(SERVER)
 
     try:
-        image = client.images.build(path='./', tag={repository})
+        os.environ["DOCKER_BUILDKIT"] = "1"
+        process = subprocess.Popen(['docker', 'build', '.', '-t', repository, '-f', 'catacomb-out/Dockerfile'], 
+                           stdout=subprocess.PIPE,
+                           universal_newlines=True)
+        ret_code = None
+        while ret_code is None:
+            ret_code = process.poll()
+
+        if ret_code != 0:
+            raise Exception(f"Failed to build image. Return code: {ret_code}")
     except Exception as error:
         print(repr(error))
-        click.echo("Something went wrong! Ensure that your Pipfile and system.py are correctly specified and try again.")
-        return
+        click.echo("Something went wrong! Some artifacts might be left over in ./catacomb-out")
+        exit(1)
 
     try:
-        os.remove("./Dockerfile")
-        os.remove("./server.py") 
+        shutil.rmtree("./catacomb-out")
     except Exception as error:
         print(repr(error))
         click.echo("Something went wrong! Ensure your system includes all the necessary components and try again.")
-        return
+        exit(1)
 
     click.echo(f'🤖 Image {repository} built!\n')
 
@@ -55,7 +66,7 @@ def push():
     except Exception as error:
         print(repr(error))
         click.echo("Something went wrong! Ensure you have the correct permissions to push to {} and try again.".format(repository))
-        return
+        exit(1)
 
     # Try adding image to Catacomb servers
     try:
@@ -66,6 +77,7 @@ def push():
     except Exception as error:
         print(repr(error))
         click.echo("Something went wrong! Double check your connection and try again.")
+        exit(1)
 
 @click.command()
 @click.option('--detach', default=False)
@@ -94,6 +106,7 @@ def start(detach, remove, port):
     except Exception as error:
         print(repr(error))
         click.echo("Something went wrong! Ensure you've run `catacomb build`.",)
+        exit(1)
 
 def login_if_required(client):
     if "DOCKER_USER" in os.environ and "DOCKER_PASSWORD" in os.environ:
